@@ -9,7 +9,7 @@
 
 __all__ = ["MokeError", "task", "stdin", "stdout", "stderr", "num", "doc",
            "INFO", "WARN", "ERROR"]
-__version__ = "1.0.5"
+__version__ = "1.1.0"
 
 
 import os
@@ -17,19 +17,19 @@ import sys
 import inspect
 import logging
 from re import search
+from path import path
 from itertools import izip_longest
 from argparse import ArgumentParser, FileType
 from types import TypeType
 from types import FileType as BaseFileType
 from ConfigParser import SafeConfigParser
 
+
 # do not remove, really
 from logging import INFO, WARN, ERROR #@UnusedImport
 from sys import stdin, stdout, stderr #@UnusedImport
 
 
-__defcfg__ = "/dev/null"
-
 __deflog__ = {"ls":stderr, # log stream
               "ll":"info", # log level
               "lf":"tab", # log format
@@ -41,6 +41,7 @@ __logforms__ = {"tab":"%(asctime)s\t%(message)s"
 nan = float("nan")
 devnull = open(os.devnull, "wb")
 
+
 # monkey patching now to have simpler code later
 file_w = FileType("wb")
 file_w.__dict__["__name__"] = "file_w"
@@ -190,9 +191,13 @@ class task(object):
         main_parser = ArgumentParser()
 
         # global options
-        main_parser.add_argument("-config", type=file_r, default=__defcfg__, 
-                                 help="(file_r) [default: None] configuration file")
-        
+        defcfg = sys.argv[0].replace(".py", ".ini")
+        if not os.path.exists(defcfg):
+            open(defcfg, "w").close()
+
+        main_parser.add_argument("-config", type=file_r, default=defcfg, 
+                                 help="(file_r) [default: %s] configuration file" % defcfg)
+
         main_parser.add_argument("-ls", type=file_a,
             default=__deflog__["ls"],
             help="(file_a) [default: %s] logging stream" % __deflog__["ls"].name)
@@ -281,13 +286,14 @@ class task(object):
 
     @classmethod
     def _callfunc(cls, args):
-        # get function and logger
-        func = args.pop("func")
-        cfg = cls._makecfg(args)
-        lgr = cls._makelgr(args, cfg)
         # where are we?
         cwd = os.getcwd()
         mokefile = os.path.abspath(os.path.join(cwd, sys.argv[0]))
+        # get config and logger
+        cfg = cls._makecfg(args)
+        lgr = cls._makelgr(args, cfg)
+        # the function
+        func = args.pop("func")
         # remember default and command line args
         names, _, _, defs = inspect.getargspec(func)
         defs = (defs or ()) # defs can be None
@@ -320,8 +326,8 @@ class task(object):
         parser = cls._funcparse()
         try:
             args = dict(parser.parse_args().__dict__)
-        except Exception:
-            return 1
+        except Exception, e:
+            sys.exit(e)
         retval = cls._callfunc(args) # modifies args
         return retval
 
